==> jc-1.4.0.tar.gz: polyglot/visit/ConstructorCallChecker.h <==
// public class polyglot.visit.ConstructorCallChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f6a7681d5cbfb9af polyglot_visit_ConstructorCallChecker
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_ConstructorCallChecker_H_
#define _JC_polyglot_visit_ConstructorCallChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_ConstructorCallChecker$sub_refs	_jc_polyglot_visit_ConstructorCallChecker$sub_refs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs	_jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$refs	_jc_polyglot_visit_ConstructorCallChecker$refs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$nonrefs	_jc_polyglot_visit_ConstructorCallChecker$nonrefs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$object	_jc_polyglot_visit_ConstructorCallChecker$object;

typedef const struct _jc_polyglot_visit_ConstructorCallChecker$vmethods	_jc_polyglot_visit_ConstructorCallChecker$vmethods;
typedef const struct _jc_polyglot_visit_ConstructorCallChecker$vtable	_jc_polyglot_visit_ConstructorCallChecker$vtable;
typedef const struct _jc_polyglot_visit_ConstructorCallChecker$vtype	_jc_polyglot_visit_ConstructorCallChecker$vtype;

// Constructors
extern void _jc_polyglot_visit_ConstructorCallChecker$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_ConstructorCallChecker$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_ConstructorCallChecker$method$enterCall$91bb061343e6f272(_jc_env *, struct _jc_polyglot_visit_ConstructorCallChecker$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ConstructorCallChecker$method_info$enterCall$91bb061343e6f272;

// Virtual methods structure
struct _jc_polyglot_visit_ConstructorCallChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$91bb061343e6f272)(_jc_env *, struct _jc_polyglot_visit_ConstructorCallChecker$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_visit_ConstructorCallChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_ConstructorCallChecker$vmethods	polyglot_visit_ConstructorCallChecker;
};

// Vtype
struct _jc_polyglot_visit_ConstructorCallChecker$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ConstructorCallChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ConstructorCallChecker$sub_refs {
	struct _jc_object	*constructorInvocations;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ConstructorCallChecker$refs {
    _jc_polyglot_visit_ConstructorCallChecker$sub_refs	polyglot_visit_ConstructorCallChecker;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ConstructorCallChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs	polyglot_visit_ConstructorCallChecker;
};

// Object instance structure
struct _jc_polyglot_visit_ConstructorCallChecker$object {
	_jc_polyglot_visit_ConstructorCallChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ConstructorCallChecker$vtype	*vtype;
	_jc_polyglot_visit_ConstructorCallChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ConstructorCallChecker$vtype _jc_polyglot_visit_ConstructorCallChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ConstructorCallChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ConstructorCallChecker$class_object;

#endif	/* _JC_polyglot_visit_ConstructorCallChecker_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/ConstructorCallChecker.h <==
// public class polyglot.visit.ConstructorCallChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f6a7681d5cbfb9af polyglot_visit_ConstructorCallChecker
// @dep_class 5c18e1d62fddfa29 polyglot_visit_ContextVisitor
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_ContextVisitor

#include "polyglot/visit/ContextVisitor.h"

#ifndef _JC_polyglot_visit_ConstructorCallChecker_H_
#define _JC_polyglot_visit_ConstructorCallChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_ConstructorCallChecker$sub_refs	_jc_polyglot_visit_ConstructorCallChecker$sub_refs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs	_jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$refs	_jc_polyglot_visit_ConstructorCallChecker$refs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$nonrefs	_jc_polyglot_visit_ConstructorCallChecker$nonrefs;
typedef struct _jc_polyglot_visit_ConstructorCallChecker$object	_jc_polyglot_visit_ConstructorCallChecker$object;

typedef const struct _jc_polyglot_visit_ConstructorCallChecker$vmethods	_jc_polyglot_visit_ConstructorCallChecker$vmethods;
typedef const struct _jc_polyglot_visit_ConstructorCallChecker$vtable	_jc_polyglot_visit_ConstructorCallChecker$vtable;
typedef const struct _jc_polyglot_visit_ConstructorCallChecker$vtype	_jc_polyglot_visit_ConstructorCallChecker$vtype;

// Constructors
extern void _jc_polyglot_visit_ConstructorCallChecker$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_ConstructorCallChecker$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_ConstructorCallChecker$method$enterCall$91bb061343e6f272(_jc_env *, struct _jc_polyglot_visit_ConstructorCallChecker$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ConstructorCallChecker$method_info$enterCall$91bb061343e6f272;

// Virtual methods structure
struct _jc_polyglot_visit_ConstructorCallChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enterCall$91bb061343e6f272)(_jc_env *, struct _jc_polyglot_visit_ConstructorCallChecker$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_ConstructorCallChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_ContextVisitor$vmethods	polyglot_visit_ContextVisitor;
	_jc_polyglot_visit_ConstructorCallChecker$vmethods	polyglot_visit_ConstructorCallChecker;
};

// Vtype
struct _jc_polyglot_visit_ConstructorCallChecker$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ConstructorCallChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ConstructorCallChecker$sub_refs {
	struct _jc_object	*constructorInvocations;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ConstructorCallChecker$refs {
    _jc_polyglot_visit_ConstructorCallChecker$sub_refs	polyglot_visit_ConstructorCallChecker;
    _jc_polyglot_visit_ContextVisitor$sub_refs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ConstructorCallChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_ContextVisitor$sub_nonrefs	polyglot_visit_ContextVisitor;
    _jc_polyglot_visit_ConstructorCallChecker$sub_nonrefs	polyglot_visit_ConstructorCallChecker;
};

// Object instance structure
struct _jc_polyglot_visit_ConstructorCallChecker$object {
	_jc_polyglot_visit_ConstructorCallChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ConstructorCallChecker$vtype	*vtype;
	_jc_polyglot_visit_ConstructorCallChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ConstructorCallChecker$vtype _jc_polyglot_visit_ConstructorCallChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ConstructorCallChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ConstructorCallChecker$class_object;

#endif	/* _JC_polyglot_visit_ConstructorCallChecker_H_ */
